@@ -5,8 +5,11 @@ logger = logging.getLogger(__name__)
 from .arrays import *
 from .comparison import *
 from .cubes import *
+from .inspect import *
 from .logic import *
 from .math import *
+from .text import *
+from .udf import *
 
 try:
     from .ml import *
@@ -18,9 +21,7 @@ except ImportError as e:
 try:
     from .experimental import *
 except ImportError as e:
-    logger.warning(
-        "Did not experimental processes due to missing dependencies: Install them like this: `pip install openeo-processes-dask[implementations, experimental]`"
-    )
+    logger.warning("Did not load experimental processes.")
 
 import rioxarray as rio  # Required for the .rio accessor on xarrays.
 
