@@ -68,17 +68,24 @@ def process(f):
             else:
                 resolved_kwargs[k] = arg
 
-        special_args = ["axis", "keepdims", "source_transposed_axis"]
+        special_args = [
+            "axis",
+            "keepdims",
+            "source_transposed_axis",
+            "context",
+            "dim_labels",
+        ]
         # Remove 'axis' and keepdims parameter if not expected in function signature.
         for arg in special_args:
             if arg not in inspect.signature(f).parameters:
                 resolved_kwargs.pop(arg, None)
 
         pretty_args = {k: repr(v)[:80] for k, v in resolved_kwargs.items()}
-        logger.info(f"Running process {f.__name__}")
-        logger.debug(
-            f"Running process {f.__name__} with resolved parameters: {pretty_args}"
-        )
+        if hasattr(f, "__name__"):
+            logger.info(f"Running process {f.__name__}")
+            logger.debug(
+                f"Running process {f.__name__} with resolved parameters: {pretty_args}"
+            )
 
         return f(*resolved_args, **resolved_kwargs)
 
