@@ -1,8 +1,12 @@
 from ._filter import *
 from .aggregate import *
 from .apply import *
+from .apply_neighborhood_intertwin import *
 from .general import *
 from .indices import *
 from .load import *
+from .mask import *
+from .mask_polygon import *
 from .merge import *
 from .reduce import *
+from .resample import *
