@@ -22,6 +22,18 @@ class ArrayElementNotAvailable(OpenEOException):
     pass
 
 
+class ArrayLabelConflict(OpenEOException):
+    pass
+
+
+class ArrayLengthMismatch(OpenEOException):
+    pass
+
+
+class LabelExists(OpenEOException):
+    pass
+
+
 class TooManyDimensions(OpenEOException):
     pass
 
@@ -80,3 +92,23 @@ class RedBandAmbiguous(OpenEOException):
 
 class BandExists(OpenEOException):
     pass
+
+
+class DimensionMismatch(OpenEOException):
+    pass
+
+
+class LabelMismatch(OpenEOException):
+    pass
+
+
+class KernelDimensionsUneven(OpenEOException):
+    pass
+
+
+class MinMaxSwapped(OpenEOException):
+    pass
+
+
+class UnitMismatch(OpenEOException):
+    pass
