@@ -1,3 +1,5 @@
+import logging
+
 import dask
 import dask.array as da
 import numpy as np
@@ -7,6 +9,7 @@ from openeo_processes_dask.process_implementations.cubes.utils import (
     _is_dask_array,
 )
 from openeo_processes_dask.process_implementations.exceptions import (
+    MinMaxSwapped,
     OpenEOException,
     QuantilesParameterConflict,
     QuantilesParameterMissing,
@@ -23,6 +26,10 @@ __all__ = [
     "add",
     "_sum",
     "_min",
+    "cumsum",
+    "cumproduct",
+    "cummin",
+    "cummax",
     "_max",
     "median",
     "mean",
@@ -61,6 +68,8 @@ __all__ = [
     "normalized_difference",
 ]
 
+logger = logging.getLogger(__name__)
+
 
 def e():
     return np.e
@@ -112,6 +121,58 @@ def _min(data, ignore_nodata=True, axis=None, keepdims=False):
         return np.min(data, axis=axis, keepdims=keepdims)
 
 
+def cumsum(data, ignore_nodata=True, axis=None):
+    nan_mask = np.isnan(data)
+
+    if ignore_nodata:
+        result = np.nancumsum(data, axis=axis)
+    else:
+        result = np.cumsum(data, axis=axis)
+
+    result[nan_mask] = np.nan
+    return result
+
+
+def cumproduct(data, ignore_nodata=True, axis=None):
+    nan_mask = np.isnan(data)
+
+    if ignore_nodata:
+        result = np.nancumprod(data, axis=axis)
+    else:
+        result = np.cumprod(data, axis=axis)
+
+    result[nan_mask] = np.nan
+    return result
+
+
+def cummin(data, ignore_nodata=True, axis=None):
+    data = np.array(data)
+    nan_mask = np.isnan(data)
+
+    if ignore_nodata:
+        data_filled = np.where(nan_mask, np.inf, data)
+        result = np.minimum.accumulate(data_filled, axis=axis)
+    else:
+        result = np.minimum.accumulate(data, axis=axis)
+
+    result[nan_mask] = np.nan
+    return result
+
+
+def cummax(data, ignore_nodata=True, axis=None):
+    data = np.array(data)
+    nan_mask = np.isnan(data)
+
+    if ignore_nodata:
+        data_filled = np.where(nan_mask, -np.inf, data)
+        result = np.maximum.accumulate(data_filled, axis=axis)
+    else:
+        result = np.maximum.accumulate(data, axis=axis)
+
+    result[nan_mask] = np.nan
+    return result
+
+
 def _max(data, ignore_nodata=True, axis=None, keepdims=False):
     if ignore_nodata:
         return np.nanmax(data, axis=axis, keepdims=keepdims)
@@ -126,21 +187,21 @@ def median(data, ignore_nodata=True, axis=None, keepdims=False):
         return np.median(data, axis=axis, keepdims=keepdims)
 
 
-def mean(data, ignore_nodata=False, axis=None, keepdims=False):
+def mean(data, ignore_nodata=True, axis=None, keepdims=False):
     if ignore_nodata:
         return np.nanmean(data, axis=axis, keepdims=keepdims)
     else:
         return np.mean(data, axis=axis, keepdims=keepdims)
 
 
-def sd(data, ignore_nodata=False, axis=None, keepdims=False):
+def sd(data, ignore_nodata=True, axis=None, keepdims=False):
     if ignore_nodata:
         return np.nanstd(data, axis=axis, ddof=1, keepdims=keepdims)
     else:
         return np.std(data, axis=axis, ddof=1, keepdims=keepdims)
 
 
-def variance(data, ignore_nodata=False, axis=None, keepdims=False):
+def variance(data, ignore_nodata=True, axis=None, keepdims=False):
     if ignore_nodata:
         return np.nanvar(data, axis=axis, ddof=1, keepdims=keepdims)
     else:
@@ -228,7 +289,10 @@ def arctan2(y, x):
 
 
 def linear_scale_range(x, inputMin, inputMax, outputMin=0.0, outputMax=1.0):
-    x = clip(x, inputMin, inputMax)
+    if inputMax < inputMin:
+        x = clip(x, inputMax, inputMin)
+    else:
+        x = clip(x, inputMin, inputMax)
     lsr = ((x - inputMin) / (inputMax - inputMin)) * (outputMax - outputMin) + outputMin
     return lsr
 
@@ -255,14 +319,20 @@ def power(base, p):
 
 
 def extrema(data, ignore_nodata=True, axis=None, keepdims=False):
+    if isinstance(data, list):
+        data = np.array(data)
     # TODO: Could be sped up by only iterating over array once
-    minimum = _min(data, skipna=ignore_nodata, axis=axis, keepdims=keepdims)
-    maximum = _max(data, skipna=ignore_nodata, axis=axis, keepdims=keepdims)
+    minimum = _min(data, ignore_nodata=ignore_nodata, axis=axis, keepdims=keepdims)
+    maximum = _max(data, ignore_nodata=ignore_nodata, axis=axis, keepdims=keepdims)
     array = dask.delayed(np.array)([minimum, maximum])
     return da.from_delayed(array, (2,), dtype=data.dtype)
 
 
 def clip(x, min, max):
+    if min > max:
+        raise MinMaxSwapped(
+            "The minimum value should be lower than or equal to the maximum value."
+        )
     # Cannot use positional arguments to pass min and max into np.clip, this will not work with dask.
     return np.clip(x, min, max)
 
@@ -280,10 +350,23 @@ def quantiles(
             "The process `quantiles` only allows that either the `probabilities` or the `q` parameter is set."
         )
 
-    if isinstance(probabilities, list):
+    if isinstance(probabilities, int):
+        probabilities = np.arange(1.0 / probabilities, 1, 1.0 / probabilities)
+
+    elif (
+        isinstance(probabilities, list)
+        and len(probabilities) == 1
+        and isinstance(probabilities[0], int)
+    ):
+        probabilities = np.arange(1.0 / probabilities[0], 1, 1.0 / probabilities[0])
+
+    elif isinstance(probabilities, list):
         probabilities = np.array(probabilities)
 
     if q is not None:
+        logger.warning(
+            "This parameter has been **deprecated**. Please use the parameter `probabilities` instead."
+        )
         probabilities = np.arange(1.0 / q, 1, 1.0 / q)
 
     if data.size == 0:
@@ -297,6 +380,8 @@ def quantiles(
         result = np.quantile(
             data, q=probabilities, method="linear", axis=axis, keepdims=keepdims
         )
+    if axis:
+        result = np.moveaxis(result, 0, axis)
 
     return result
 
